@@ -116,7 +116,7 @@ class SessionMiddleware:
 
         await self.app(scope, receive, send_wrapper)
 
-    async def _get_predefined_session_backend(self, backend_db_client) -> ISessionBackend:
+    def _get_predefined_session_backend(self, backend_db_client) -> ISessionBackend:
         if self.backend_type == BackendType.redis:
             return RedisSessionBackend(backend_db_client)
         elif self.backend_type == BackendType.cookie:
